@@ -1,6 +1,6 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: buildhash.c,v 1.75 2008-02-21 01:55:36-08 geoff Exp $";
+    "$Id: buildhash.c,v 1.76 2020-12-30 22:33:41-08 geoff Exp $";
 #endif
 
 #define MAIN
@@ -47,6 +47,9 @@ static char Rcs_Id[] =
 
 /*
  * $Log: buildhash.c,v $
+ * Revision 1.76  2020-12-30 22:33:41-08  geoff
+ * Add the character-set options to the hash file.
+ *
  * Revision 1.75  2008-02-21 01:55:36-08  geoff
  * When the hash teable overflows, null out the "next" pointer so that if
  * the table is used, ispell won't follow a garbage pointer and crash.
@@ -342,6 +345,8 @@ static void output ()
 	n++;
 	(void) fwrite (chartypes[i].suffixes, n, 1, houtfile);
 	strptr += n;
+	(void) fwrite (&chartypes[i].options, 1, 1, houtfile);
+	strptr++;
 	}
     hashheader.lstringsize = strptr;
     /* We allow one extra byte because missingletter() may add one byte */
