@@ -1,11 +1,18 @@
 #ifndef lint
 static char Rcs_Id[] =
-    "$Id: fields.c,v 1.11 2005/04/14 14:38:23 geoff Exp $";
+    "$Id: fields.c,v 1.13 2021-06-02 16:52:07-07 geoff Exp $";
 #endif
 
 /*
  * $Log: fields.c,v $
- * Revision 1.11  2005/04/14 14:38:23  geoff
+ * Revision 1.13  2021-06-02 16:52:07-07  geoff
+ * When maxf is nonzero, don't truncate the last field.  Get rid of
+ * O(N^2) performance when expanding buffers.  Remove FLD_NOSHRINK.
+ *
+ * Revision 1.12  2021-05-29 22:53:37-07  geoff
+ * Correctly handle quoted strings in the last field on a line.
+ *
+ * Revision 1.11  2005-04-14 07:38:23-07  geoff
  * Make maxf unsigned.
  *
  * Revision 1.10  1999/01/06 20:57:19  geoff
@@ -65,8 +72,8 @@ int		fieldwrite P ((FILE * file, field_t * fieldp, int delim));
 void		fieldfree P ((field_t * fieldp));
 				/* Free a field returned by fieldread */
 
-unsigned int	field_field_inc = 20; /* Increment to increase # fields by */
-unsigned int	field_line_inc = 512; /* Incr to increase line length by */
+#define INIT_FIELDS     8       /* Number of fields to allocate initially */
+#define INIT_LINE       128     /* Initial size of a line in fieldread */
 
 #ifndef USG
 #define strchr	index
@@ -87,10 +94,10 @@ field_t * fieldread (file, delims, flags, maxf)
     int			linemax; /* Maximum line buffer size */
     int			linesize; /* Current line buffer size */
 
-    linebuf = (char *) malloc (field_line_inc);
+    linebuf = (char *) malloc (INIT_LINE);
     if (linebuf == NULL)
 	return NULL;
-    linemax = field_line_inc;
+    linemax = INIT_LINE;
     linesize = 0;
     /*
      * Read in the line.
@@ -103,7 +110,7 @@ field_t * fieldread (file, delims, flags, maxf)
 	    break;
 	else
 	    {
-	    linemax += field_line_inc;
+	    linemax *= 2;
 	    linebuf = (char *) realloc (linebuf, linemax);
 	    if (linebuf == NULL)
 		return NULL;
@@ -140,19 +147,6 @@ field_t * fieldmake (line, allocated, delims, flags, maxf)
 	line[--linesize] = '\0';
 	fieldp->hadnl = 1;
 	}
-    /*
-     * Shrink the line buffer if necessary.
-     */
-    if (allocated  &&  (flags & FLD_NOSHRINK) == 0)
-	{
-	line = fieldp->linebuf =
-	  (char *) realloc (fieldp->linebuf, linesize + 1);
-	if (fieldp->linebuf == NULL)
-	    {
-	    fieldfree (fieldp);
-	    return NULL;
-	    }
-	}
     return fieldparse (fieldp, line, delims, flags, maxf);
     }
 
@@ -169,7 +163,7 @@ static field_t * fieldparse (fieldp, line, delims, flags, maxf)
 
     fieldp->nfields = 0;
     fieldmax =
-      (maxf != 0  &&  maxf < field_field_inc) ? maxf + 2 : field_field_inc;
+      (maxf != 0  &&  maxf < INIT_FIELDS) ? maxf + 2 : INIT_FIELDS;
     fieldp->fields = (char **) malloc (fieldmax * sizeof (char *));
     if (fieldp->fields == NULL)
 	{
@@ -281,13 +275,16 @@ static field_t * fieldparse (fieldp, line, delims, flags, maxf)
 	    }
 	fieldp->nfields++;
 	if (*line++ == '\0')
+	    {
+	    *lineout = '\0';
 	    break;
+	    }
 	if (maxf != 0  &&  fieldp->nfields > maxf)
 	    break;
 	*lineout = '\0';
 	if (fieldp->nfields >= fieldmax)
 	    {
-	    fieldmax += field_field_inc;
+	    fieldmax *= 2;
 	    fieldp->fields =
 	      (char **) realloc (fieldp->fields, fieldmax * sizeof (char *));
 	    if (fieldp->fields == NULL)
@@ -297,19 +294,6 @@ static field_t * fieldparse (fieldp, line, delims, flags, maxf)
 		}
 	    }
 	}
-    /*
-     * Shrink the field pointers and return the field structure.
-     */
-    if ((flags & FLD_NOSHRINK) == 0  &&  fieldp->nfields >= fieldmax)
-	{
-	fieldp->fields = (char **) realloc (fieldp->fields,
-	  (fieldp->nfields + 1) * sizeof (char *));
-	if (fieldp->fields == NULL)
-	    {
-	    fieldfree (fieldp);
-	    return NULL;
-	    }
-	}
     fieldp->fields[fieldp->nfields] = NULL;
     return fieldp;
     }
