@@ -10,7 +10,7 @@
  */
 
 static char * Version_ID[] = {
-    "@(#) International Ispell Version 3.4.02 08 Jan 2021",
+    "@(#) International Ispell Version 3.4.05 11 Mar 2022",
     "@(#) Copyright (c), 1983, by Pace Willisson",
     "@(#) International version Copyright (c) 1987, 1988, 1990-1995, 1999,",
     "@(#) 2001, 2002, 2005, 2015, 2021 by Geoff Kuenning, Claremont, CA.",
@@ -18,7 +18,7 @@ static char * Version_ID[] = {
     "@(#)",
     "@(#) The official ispell Web site is at:",
     "@(#)",
-    "@(#)     http://www.cs.hmc.edu/geoff/ispell.html",
+    "@(#)     http://www.cs.hmc.edu/~geoff/ispell.html",
     "@(#)",
     "@(#) You should always check that site to see whether you have the",
     "@(#) latest version of ispell.",
@@ -63,6 +63,6 @@ static char * Version_ID[] = {
 };
 
 static char RCS_Version_ID[] =
-    "$Id: version.h,v 1.62 2021-01-09 13:12:35-08 geoff Exp $";
+    "$Id: version.h,v 1.67 2022-03-11 00:30:26-08 geoff Exp $";
 
 #endif /* VERSION_H_INCLUDED */
